cumulusci.salesforce\_api package
=================================

Subpackages
-----------

.. toctree::

    cumulusci.salesforce_api.tests

Submodules
----------

cumulusci.salesforce\_api.exceptions module
-------------------------------------------

.. automodule:: cumulusci.salesforce_api.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce\_api.metadata module
-----------------------------------------

.. automodule:: cumulusci.salesforce_api.metadata
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce\_api.package\_zip module
---------------------------------------------

.. automodule:: cumulusci.salesforce_api.package_zip
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce\_api.soap\_envelopes module
------------------------------------------------

.. automodule:: cumulusci.salesforce_api.soap_envelopes
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.salesforce_api
    :members:
    :undoc-members:
    :show-inheritance:
